@@ -1,4 +1,3 @@
-__version__ = "0.1.0"
 __author__ = "Fernando Domínguez"
 __credits__ = "Joxean Koret"
 
@@ -7,8 +6,7 @@ from .diaphora import (
     get_function_details, get_db_attrs, get_db_attrs_path, drop_all,
     drop_db, db_exists as sample_db_exists
 )
+from .idaapi.idaapi_to_r2 import get_all_fns, strings, string_values, r2_open, r2_close
 from .html_diff import HtmlResults
 
-def version():
-    return __version__
 
